Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(618)

Unified Diff: net/dns/dns_transaction_unittest.cc

Issue 1398973003: Don't use base::MessageLoop::{Quit,QuitClosure} in net/ (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/dns/dns_config_service_unittest.cc ('k') | net/dns/host_resolver_impl_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/dns/dns_transaction_unittest.cc
diff --git a/net/dns/dns_transaction_unittest.cc b/net/dns/dns_transaction_unittest.cc
index f5a897390a5e640a992a2ce06f04c45983cb8772..dc0644aba95caa7f7440cf2c0eff073f5cf01f24 100644
--- a/net/dns/dns_transaction_unittest.cc
+++ b/net/dns/dns_transaction_unittest.cc
@@ -236,7 +236,7 @@ class TransactionHelper {
cancel_in_callback_ = true;
}
// Mark to call MessageLoop::Quit() upon callback.
void set_quit_in_callback() {
quit_in_callback_ = true;
}
@@ -274,7 +274,7 @@ class TransactionHelper {
// Tell MessageLoop to quit now, in case any ASSERT_* fails.
if (quit_in_callback_)
- base::MessageLoop::current()->Quit();
+ base::MessageLoop::current()->QuitWhenIdle();
if (expected_answer_count_ >= 0) {
ASSERT_EQ(OK, rv);
« no previous file with comments | « net/dns/dns_config_service_unittest.cc ('k') | net/dns/host_resolver_impl_unittest.cc » ('j') | no next file with comments »
@@ -236,7 +236,7 @@ class TransactionHelper {
cancel_in_callback_ = true;
}
- // Mark to call MessageLoop::Quit() upon callback.
+ // Mark to call MessageLoop::QuitWhenIdle() upon callback.
void set_quit_in_callback() {
quit_in_callback_ = true;

Powered by Google App Engine
This is Rietveld 408576698